==> types_boto3_full-1.35.74-py3-none-any.whl: types_boto3_events/paginator.py <==
"""
Type annotations for events service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_events/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_events.client import EventBridgeClient
    from types_boto3_events.paginator import (
        ListRuleNamesByTargetPaginator,
        ListRulesPaginator,
        ListTargetsByRulePaginator,
    )

    session = Session()
    client: EventBridgeClient = session.client("events")

    list_rule_names_by_target_paginator: ListRuleNamesByTargetPaginator = client.get_paginator("list_rule_names_by_target")
    list_rules_paginator: ListRulesPaginator = client.get_paginator("list_rules")
    list_targets_by_rule_paginator: ListTargetsByRulePaginator = client.get_paginator("list_targets_by_rule")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListRuleNamesByTargetRequestListRuleNamesByTargetPaginateTypeDef,
    ListRuleNamesByTargetResponseTypeDef,
    ListRulesRequestListRulesPaginateTypeDef,
    ListRulesResponseTypeDef,
    ListTargetsByRuleRequestListTargetsByRulePaginateTypeDef,
    ListTargetsByRuleResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ListRuleNamesByTargetPaginator", "ListRulesPaginator", "ListTargetsByRulePaginator")


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class ListRuleNamesByTargetPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/events/paginator/ListRuleNamesByTarget.html#EventBridge.Paginator.ListRuleNamesByTarget)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_events/paginators/#listrulenamesbytargetpaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListRuleNamesByTargetRequestListRuleNamesByTargetPaginateTypeDef]
    ) -> _PageIterator[ListRuleNamesByTargetResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/events/paginator/ListRuleNamesByTarget.html#EventBridge.Paginator.ListRuleNamesByTarget.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_events/paginators/#listrulenamesbytargetpaginator)
        """


class ListRulesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/events/paginator/ListRules.html#EventBridge.Paginator.ListRules)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_events/paginators/#listrulespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListRulesRequestListRulesPaginateTypeDef]
    ) -> _PageIterator[ListRulesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/events/paginator/ListRules.html#EventBridge.Paginator.ListRules.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_events/paginators/#listrulespaginator)
        """


class ListTargetsByRulePaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/events/paginator/ListTargetsByRule.html#EventBridge.Paginator.ListTargetsByRule)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_events/paginators/#listtargetsbyrulepaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListTargetsByRuleRequestListTargetsByRulePaginateTypeDef]
    ) -> _PageIterator[ListTargetsByRuleResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/events/paginator/ListTargetsByRule.html#EventBridge.Paginator.ListTargetsByRule.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_events/paginators/#listtargetsbyrulepaginator)
        """

==> types_boto3_full-1.35.91-py3-none-any.whl: types_boto3_events/paginator.py <==
"""
Type annotations for events service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_events/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_events.client import EventBridgeClient
    from types_boto3_events.paginator import (
        ListRuleNamesByTargetPaginator,
        ListRulesPaginator,
        ListTargetsByRulePaginator,
    )

    session = Session()
    client: EventBridgeClient = session.client("events")

    list_rule_names_by_target_paginator: ListRuleNamesByTargetPaginator = client.get_paginator("list_rule_names_by_target")
    list_rules_paginator: ListRulesPaginator = client.get_paginator("list_rules")
    list_targets_by_rule_paginator: ListTargetsByRulePaginator = client.get_paginator("list_targets_by_rule")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListRuleNamesByTargetRequestPaginateTypeDef,
    ListRuleNamesByTargetResponseTypeDef,
    ListRulesRequestPaginateTypeDef,
    ListRulesResponseTypeDef,
    ListTargetsByRuleRequestPaginateTypeDef,
    ListTargetsByRuleResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ListRuleNamesByTargetPaginator", "ListRulesPaginator", "ListTargetsByRulePaginator")


if TYPE_CHECKING:
    _ListRuleNamesByTargetPaginatorBase = Paginator[ListRuleNamesByTargetResponseTypeDef]
else:
    _ListRuleNamesByTargetPaginatorBase = Paginator  # type: ignore[assignment]


class ListRuleNamesByTargetPaginator(_ListRuleNamesByTargetPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/events/paginator/ListRuleNamesByTarget.html#EventBridge.Paginator.ListRuleNamesByTarget)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_events/paginators/#listrulenamesbytargetpaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListRuleNamesByTargetRequestPaginateTypeDef]
    ) -> PageIterator[ListRuleNamesByTargetResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/events/paginator/ListRuleNamesByTarget.html#EventBridge.Paginator.ListRuleNamesByTarget.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_events/paginators/#listrulenamesbytargetpaginator)
        """


if TYPE_CHECKING:
    _ListRulesPaginatorBase = Paginator[ListRulesResponseTypeDef]
else:
    _ListRulesPaginatorBase = Paginator  # type: ignore[assignment]


class ListRulesPaginator(_ListRulesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/events/paginator/ListRules.html#EventBridge.Paginator.ListRules)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_events/paginators/#listrulespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListRulesRequestPaginateTypeDef]
    ) -> PageIterator[ListRulesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/events/paginator/ListRules.html#EventBridge.Paginator.ListRules.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_events/paginators/#listrulespaginator)
        """


if TYPE_CHECKING:
    _ListTargetsByRulePaginatorBase = Paginator[ListTargetsByRuleResponseTypeDef]
else:
    _ListTargetsByRulePaginatorBase = Paginator  # type: ignore[assignment]


class ListTargetsByRulePaginator(_ListTargetsByRulePaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/events/paginator/ListTargetsByRule.html#EventBridge.Paginator.ListTargetsByRule)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_events/paginators/#listtargetsbyrulepaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListTargetsByRuleRequestPaginateTypeDef]
    ) -> PageIterator[ListTargetsByRuleResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/events/paginator/ListTargetsByRule.html#EventBridge.Paginator.ListTargetsByRule.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_events/paginators/#listtargetsbyrulepaginator)
        """
